pub struct GlsTracker;Trait Implementations
Sourceimpl Tracker for GlsTracker
impl Tracker for GlsTracker
Sourcefn can_handle(&self, url: &str) -> bool
fn can_handle(&self, url: &str) -> bool
Lets caller code know whether the Tracker implementation is suitable for
the given url, so that caller code can do dynamic dispatch.
Sourcefn get_raw<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
url: &'life1 str,
ctx: &'life2 TrackerContext<'_>,
) -> Pin<Box<dyn Future<Output = Result<String>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
fn get_raw<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
url: &'life1 str,
ctx: &'life2 TrackerContext<'_>,
) -> Pin<Box<dyn Future<Output = Result<String>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
Get raw data that can be cached
Using String as the data type because we can’t guarantee the format of
the reponse (HTML / JSON etc).
Result because the request may not succeedAuto Trait Implementations
impl Freeze for GlsTracker
impl RefUnwindSafe for GlsTracker
impl Send for GlsTracker
impl Sync for GlsTracker
impl Unpin for GlsTracker
impl UnsafeUnpin for GlsTracker
impl UnwindSafe for GlsTracker